summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--release-notes.md1
-rw-r--r--src/StardewModdingAPI/Program.cs4
2 files changed, 3 insertions, 2 deletions
diff --git a/release-notes.md b/release-notes.md
index 171ba010..86169cee 100644
--- a/release-notes.md
+++ b/release-notes.md
@@ -7,6 +7,7 @@ For players:
* Fixed compatibility with some older mods.
* Fixed mod errors in most event handlers crashing the game.
* Fixed mod errors in some event handlers preventing other mods from receiving the same event.
+ * Fixed game crashing on startup with an audio error for some players.
For developers:
* Improved logging to show `ReflectionTypeLoadException` details when it's caught by SMAPI.
diff --git a/src/StardewModdingAPI/Program.cs b/src/StardewModdingAPI/Program.cs
index 14dbafc9..d31a1d39 100644
--- a/src/StardewModdingAPI/Program.cs
+++ b/src/StardewModdingAPI/Program.cs
@@ -134,8 +134,8 @@ namespace StardewModdingAPI
return;
}
- // check for update
- Program.CheckForUpdateAsync();
+ // check for update when game loads
+ GameEvents.GameLoaded += (sender, e) => Program.CheckForUpdateAsync();
// launch game
Program.StartGame();